## 📝 Description

Please provide a clear and concise description of the changes in this pull request.

## ✔️ Checklist

- [ ] I have read the [**CONTRIBUTING.md**](CONTRIBUTING.md) document.
- [ ] My code follows the style guidelines of this project.
- [ ] I have added tests to cover my changes.
- [ ] I have added an example in the `examples/` directory (if applicable).
- [ ] I have updated the documentation (if applicable).
- [ ] I have performed a self-review of my code.
- [ ] I have commented on my code, especially in hard-to-understand areas.
- [ ] I have run the code locally and verified that it works as expected.
- [ ] All new and existing tests passed.
- [ ] I have updated the `docs/CHANGELOG.md` file.

## 🔗 Related Issues

Closes # (if applicable)
